/*
 * This is a sample script to create and schedule a job for purging offline execution jobs
 * in the Noilo database. 
 * Stored procedure sp_purge_execution_jobs must be created before the job starts.
 *
 * For information on creating job and its limitations and security, please reference
 *   http://technet.microsoft.com/en-us/library/ms190268.aspx#Security
 */

-- create the job
BEGIN TRY
    BEGIN TRAN

    DECLARE @jobId BINARY(16)

    --Add job
    EXEC msdb.dbo.sp_add_job @job_name=N'Nolio Purge - offline execution jobs', @job_id = @jobId OUTPUT

    --Add step to job
    --Call sp_purge_execution_jobs to delete offline execution jobs older than 120 days.  
    --Schedule the procedure to run for approximately 1 hour (3600 seconds).  The job may
    --takes longer depending on the time it takes for the last command to finish.
    --
    --*** NOTE ***  Update @database_name to the appropriate database name
    --
    EXEC msdb.dbo.sp_add_jobstep @job_id=@jobId, @step_name=N'exec purge procedure', 
    		@step_id=1, 
    		@subsystem=N'TSQL', 
    		@command=N'sp_purge_execution_jobs @retention_days=120, @time_limit=3600' /*change if needed*/, 
    		@database_name=N'nolio_db' /*change if needed*/, 
    		@flags=0

    --Add schedule to job
    --The command schedule below schedule the job to execute daily at midnight.
    EXEC msdb.dbo.sp_add_jobschedule @job_id=@jobId, @name=N'daily @midnight', 
    		@freq_type=4, 
    		@freq_interval=1, 
    		@freq_subday_type=1, 
    		@freq_subday_interval=0, 
    		@freq_relative_interval=0, 
    		@freq_recurrence_factor=0, 
    		@active_start_date=20131120 /*change if needed*/, 
    		@active_end_date=99991231, 
    		@active_start_time=0, 
    		@active_end_time=235959

    EXEC msdb.dbo.sp_add_jobserver  @job_id=@jobId

    COMMIT TRAN
END TRY
BEGIN CATCH
    SELECT ERROR_Message(), ERROR_Line();
    ROLLBACK TRAN
END CATCH

/*
-- query job info
EXEC msdb.dbo.sp_help_job
    @job_name = N'nolio_TR backup job',
    @job_aspect = N'ALL' ;
GO

*/

 
